@@ -32,18 +32,17 @@ import gobject
 try:
     import gconf
 except:
-    have_gconf=False
+    HAVE_GCONF = False
 else:
-    have_gconf=True
+    HAVE_GCONF = True
 
-import pitivi.instance as instance
 import pitivi.configure as configure
 from pitivi.projectsaver import ProjectSaver
 
 from gettext import gettext as _
 
-from timeline import TimelineWidget
-from sourcefactories import SourceFactoriesWidget
+from timeline import Timeline
+from projecttabs import ProjectTabs
 from viewer import PitiviViewer
 from pitivi.bin import SmartTimelineBin
 from projectsettings import ProjectSettingsDialog
@@ -55,16 +54,34 @@ from pitivi.configure import pitivi_version, APPNAME
 from glade import GladeWindow
 from exportsettingswidget import ExportSettingsDialog
 
-import dbus
-import dbus.service
-import dbus.glib
-
-if have_gconf:
+if HAVE_GCONF:
     D_G_INTERFACE = "/desktop/gnome/interface"
 
-    for gconf_dir in (D_G_INTERFACE,):
+    for gconf_dir in (D_G_INTERFACE, ):
         gconf.client_get_default ().add_dir (gconf_dir, gconf.CLIENT_PRELOAD_NONE)
 
+def create_stock_icons():
+    """ Creates the pitivi-only stock icons """
+    gtk.stock_add([
+            ('pitivi-render', 'Render', 0, 0, 'pitivi'),
+            ('pitivi-split', 'Split', 0, 0, 'pitivi'),
+            ('pitivi-unlink', 'Unlink', 0, 0, 'pitivi'),
+            ('pitivi-relink', 'Relink', 0, 0, 'pitivi'),
+            ])
+    pixmaps = {
+        "pitivi-render" : "pitivi-render-24.png",
+        "pitivi-split" : "pitivi-split.svg",
+        "pitivi-unlink" : "pitivi-unlink.svg",
+        "pitivi-relink" : "pitivi-relink.svg",
+    }
+    factory = gtk.IconFactory()
+    pmdir = configure.get_pixmap_dir()
+    for stockid, path in pixmaps.iteritems():
+        pixbuf = gtk.gdk.pixbuf_new_from_file(os.path.join(pmdir, path))
+        iconset = gtk.IconSet(pixbuf)
+        factory.add(stockid, iconset)
+        factory.add_default()
+
 
 class PitiviMainWindow(gtk.Window):
     """
@@ -72,62 +89,53 @@ class PitiviMainWindow(gtk.Window):
     """
 
 
-    def __init__(self):
+    def __init__(self, instance):
         """ initialize with the Pitivi object """
         gst.log("Creating MainWindow")
         gtk.Window.__init__(self)
-
-        self._createStockIcons()
-        self._setActions()
-        self._createUi()
         self.actions = None
         self.toggleactions = None
         self.actiongroup = None
+        self.is_fullscreen = False
+        self.error_dialogbox = None
+        self.pitivi = instance
 
-        self.isFullScreen = False
-        self.errorDialogBox = None
-
-        instance.PiTiVi.connect("new-project-loaded", self._newProjectLoadedCb)
-        instance.PiTiVi.connect("new-project-loading", self._newProjectLoadingCb)
-        instance.PiTiVi.connect("closing-project", self._closingProjectCb)
-        instance.PiTiVi.connect("new-project-failed", self._notProjectCb)
-        instance.PiTiVi.current.connect("save-uri-requested", self._saveAsDialogCb)
-        instance.PiTiVi.current.connect("confirm-overwrite", self._confirmOverwriteCb)
-        instance.PiTiVi.playground.connect("error", self._playGroundErrorCb)
-        instance.PiTiVi.current.sources.connect_after("file_added", self._sourcesFileAddedCb)
-
-        # Start dbus service
-        session_bus = dbus.SessionBus()
-        name = dbus.service.BusName("org.gnome.pitivi", bus=session_bus)
-        object = pitivi_dbus(name)
-
-
-        # FIXME : connect to the device probe signals to toggle the webcam
-        # features based on availability (or not) of webcams.
+    def load(self):
+        """ load the user interface """
+        create_stock_icons()
+        self._setActions()
+        self._createUi()
+        self.pitivi.connect("new-project-loaded", self._newProjectLoadedCb)
+        self.pitivi.connect("new-project-loading", self._newProjectLoadingCb)
+        self.pitivi.connect("closing-project", self._closingProjectCb)
+        self.pitivi.connect("new-project-failed", self._notProjectCb)
+        self.pitivi.current.connect("save-uri-requested", self._saveAsDialogCb)
+        self.pitivi.current.connect("confirm-overwrite", self._confirmOverwriteCb)
+        self.pitivi.playground.connect("error", self._playGroundErrorCb)
+        self.pitivi.current.sources.connect("file_added", self._sourcesFileAddedCb)
 
         # if no webcams available, hide the webcam action
-        instance.PiTiVi.deviceprobe.connect("device-added", self.__deviceChangeCb)
-        instance.PiTiVi.deviceprobe.connect("device-removed", self.__deviceChangeCb)
-        if len(instance.PiTiVi.deviceprobe.getVideoSourceDevices()) < 1:
+        self.pitivi.deviceprobe.connect("device-added", self.__deviceChangeCb)
+        self.pitivi.deviceprobe.connect("device-removed", self.__deviceChangeCb)
+        if len(self.pitivi.deviceprobe.getVideoSourceDevices()) < 1:
             self.webcam_button.set_sensitive(False)
-
         self.show_all()
 
     def _encodingDialogDestroyCb(self, unused_dialog):
-        instance.PiTiVi.gui.set_sensitive(True)
+        self.pitivi.gui.set_sensitive(True)
 
     def _recordCb(self, unused_button):
         # pause timeline !
-        instance.PiTiVi.playground.pause()
+        self.pitivi.playground.pause()
 
-        win = EncodingDialog(instance.PiTiVi.current)
+        win = EncodingDialog(self.pitivi.current, self.pitivi)
         win.window.connect("destroy", self._encodingDialogDestroyCb)
-        instance.PiTiVi.gui.set_sensitive(False)
+        self.pitivi.gui.set_sensitive(False)
         win.show()
 
     def _timelineDurationChangedCb(self, unused_composition, unused_start,
                                    duration):
-        if not isinstance(instance.PiTiVi.playground.current, SmartTimelineBin):
+        if not isinstance(self.pitivi.playground.current, SmartTimelineBin):
             return
         self.render_button.set_sensitive((duration > 0) and True or False)
 
@@ -147,22 +155,6 @@ class PitiviMainWindow(gtk.Window):
             else:
                 self.render_button.set_sensitive(False)
 
-    def _createStockIcons(self):
-        """ Creates the pitivi-only stock icons """
-        gtk.stock_add([
-                ('pitivi-advanced-mode', 'Advanced Mode', 0, 0, 'pitivi'),
-                ('pitivi-render', 'Render', 0, 0, 'pitivi')
-                ])
-        factory = gtk.IconFactory()
-        pixbuf = gtk.gdk.pixbuf_new_from_file(
-            configure.get_pixmap_dir() + "/pitivi-advanced-24.png")
-        iconset = gtk.IconSet(pixbuf)
-        factory.add('pitivi-advanced-mode', iconset)
-        pixbuf = gtk.gdk.pixbuf_new_from_file(
-            configure.get_pixmap_dir() + "/pitivi-render-24.png")
-        iconset = gtk.IconSet(pixbuf)
-        factory.add('pitivi-render', iconset)
-        factory.add_default()
 
 
     def _setActions(self):
@@ -178,11 +170,6 @@ class PitiviMainWindow(gtk.Window):
              None, _("Save the current project"), self._saveProjectAsCb),
             ("ProjectSettings", gtk.STOCK_PROPERTIES, _("Project settings"),
              None, _("Edit the project settings"), self._projectSettingsCb),
-            ("ImportSources", gtk.STOCK_ADD, _("_Import clips..."),
-             None, _("Import clips to use"), self._importSourcesCb),
-            ("ImportSourcesFolder", gtk.STOCK_ADD,
-             _("_Import folder of clips..."), None,
-             _("Import folder of clips to use"), self._importSourcesFolderCb),
             ("RenderProject", 'pitivi-render' , _("_Render project"),
              None, _("Render project"), self._recordCb),
             ("PluginManager", gtk.STOCK_PREFERENCES ,
@@ -207,8 +194,6 @@ class PitiviMainWindow(gtk.Window):
         ]
 
         self.toggleactions = [
-            ("AdvancedView", 'pitivi-advanced-mode', _("Advanced vie_w"),
-             None, _("Switch to advanced view"), self._advancedViewCb, True),
             ("FullScreen", gtk.STOCK_FULLSCREEN, None, None,
              _("View the main window on the whole screen"), self._fullScreenCb)
         ]
@@ -224,9 +209,6 @@ class PitiviMainWindow(gtk.Window):
                 self.render_button = action
             elif action.get_name() == "ImportfromCam":
                 self.webcam_button = action
-            elif action.get_name() == "AdvancedView":
-                if not instance.PiTiVi.settings.advancedModeEnabled:
-                    action.set_sensitive(False)
             elif action.get_name() == "Screencast":
                 # FIXME : re-enable this action once istanbul integration is complete
                 # and upstream istanbul has applied packages for proper interaction.
@@ -234,16 +216,16 @@ class PitiviMainWindow(gtk.Window):
             elif action.get_name() in [
                 "ProjectSettings", "Quit", "File", "Edit", "Help",
                 "About", "View", "FullScreen", "ImportSources",
-                "ImportSourcesFolder", "AdvancedView", "PluginManager","ImportfromCam","NetstreamCapture"]:
+                "ImportSourcesFolder", "PluginManager","ImportfromCam","NetstreamCapture"]:
                 action.set_sensitive(True)
             elif action.get_name() in ["SaveProject", "SaveProjectAs",
                     "NewProject", "OpenProject"]:
-                if not instance.PiTiVi.settings.fileSupportEnabled:
+                if not self.pitivi.settings.fileSupportEnabled:
                     action.set_sensitive(False)
             else:
                 action.set_sensitive(False)
 
-        self.uimanager = instance.PiTiVi.uimanager
+        self.uimanager = gtk.UIManager()
         self.add_accel_group(self.uimanager.get_accel_group())
         self.uimanager.insert_action_group(self.actiongroup, 0)
         self.uimanager.add_ui_from_file(os.path.join(os.path.dirname(
@@ -255,42 +237,38 @@ class PitiviMainWindow(gtk.Window):
         """ Create the graphical interface """
         self.set_title("%s v%s" % (APPNAME, pitivi_version))
         self.set_geometry_hints(min_width=800, min_height=480)
-
         self.connect("destroy", self._destroyCb)
 
+        # main menu & toolbar
         vbox = gtk.VBox(False)
         self.add(vbox)
-
         self.menu = self.uimanager.get_widget("/MainMenuBar")
         vbox.pack_start(self.menu, expand=False)
-
         self.toolbar = self.uimanager.get_widget("/MainToolBar")
-
         vbox.pack_start(self.toolbar, expand=False)
 
-
+        # timeline and project tabs
         vpaned = gtk.VPaned()
         vbox.pack_start(vpaned)
-
-        self.timeline = TimelineWidget()
-        self.timeline.showComplexView()
-
-        vpaned.pack2(self.timeline, resize=False, shrink=True)
-
+        self.timeline = Timeline()
+        vpaned.pack2(self.timeline, resize=True, shrink=False)
         hpaned = gtk.HPaned()
-        vpaned.pack1(hpaned, resize=True, shrink=False)
-
-        # source-and-effects list
-        self.sourcefactories = SourceFactoriesWidget()
+        vpaned.pack1(hpaned, resize=False, shrink=True)
+        self.projecttabs = ProjectTabs()
+        hpaned.pack1(self.projecttabs, resize=True, shrink=False)
 
         # Viewer
         self.viewer = PitiviViewer()
-
-        instance.PiTiVi.playground.connect("current-changed", 
+        self.pitivi.playground.connect("current-changed", 
             self._currentPlaygroundChangedCb)
+        hpaned.pack2(self.viewer, resize=False, shrink=False)
+        #self.viewer.detach_button.connect("clicked", self.__windowizeViewer, 
+        #    hpaned)
 
-        hpaned.pack1(self.sourcefactories, resize=False, shrink=False)
-        hpaned.pack2(self.viewer, resize=True, shrink=False)
+        # set a reasonable default
+        vpaned.set_position(200)
+
+        # timeline toolbar
         # FIXME: remove toolbar padding and shadow. In fullscreen mode, the
         # toolbar buttons should be clickable with the mouse cursor at the
         # very bottom of the screen.
@@ -303,19 +281,33 @@ class PitiviMainWindow(gtk.Window):
 
     def toggleFullScreen(self):
         """ Toggle the fullscreen mode of the application """
-        if not self.isFullScreen:
+        if not self.is_fullscreen:
             self.viewer.window.fullscreen()
-            self.isFullScreen = True
+            self.is_fullscreen = True
         else:
             self.viewer.window.unfullscreen()
-            self.isFullScreen = False
+            self.is_fullscreen = False
 
 ## PlayGround callback
 
+    def __windowizeViewer(self, button, pane):
+        # FIXME: the viewer can't seem to handle being unparented/reparented
+        pane.remove(self.viewer)
+        window = gtk.Window()
+        window.add(self.viewer)
+        window.connect("destroy", self.__reparentViewer, pane)
+        window.resize(200, 200)
+        window.show_all()
+
+    def __reparentViewer(self, window, pane):
+        window.remove(self.viewer)
+        pane.pack2(self.viewer, resize=False, shrink=False)
+        self.viewer.show()
+
     def _errorMessageResponseCb(self, dialogbox, unused_response):
         dialogbox.hide()
         dialogbox.destroy()
-        self.errorDialogBox = None
+        self.error_dialogbox = None
 
     def _playGroundErrorCb(self, unused_playground, error, detail):
         # FIXME FIXME FIXME:
@@ -325,38 +317,27 @@ class PitiviMainWindow(gtk.Window):
         # some ways of actually _dealing_ with the underlying problem:
         # install a plugin, re-conform source to some other format, or
         # maybe even disable playback of a problematic file.
-        if self.errorDialogBox:
+        if self.error_dialogbox:
             return
-        self.errorDialogBox = gtk.MessageDialog(None, gtk.DIALOG_MODAL,
+        self.error_dialogbox = gtk.MessageDialog(None, gtk.DIALOG_MODAL,
             gtk.MESSAGE_ERROR, gtk.BUTTONS_OK, None)
-        self.errorDialogBox.set_markup("<b>%s</b>" % error)
-        self.errorDialogBox.connect("response", self._errorMessageResponseCb)
+        self.error_dialogbox.set_markup("<b>%s</b>" % error)
+        self.error_dialogbox.connect("response", self._errorMessageResponseCb)
         if detail:
-            self.errorDialogBox.format_secondary_text(detail)
-        self.errorDialogBox.show()
+            self.error_dialogbox.format_secondary_text(detail)
+        self.error_dialogbox.show()
 
 ## Project source list callbacks
 
     def _sourcesFileAddedCb(self, unused_sources, unused_factory):
         #if (len(self.sourcefactories.sourcelist.storemodel) == 1 
-        #    and not len(instance.PiTiVi.current.timeline.videocomp):
+        #    and not len(self.pitivi.current.timeline.videocomp):
         pass
 
 ## UI Callbacks
 
-    def _destroyCb(self, unused_widget, data=None):
-
-        # Quit connection to istanbul/switch off savemode
-        try:
-            bus = dbus.SessionBus()
-            remote_object = bus.get_object("org.gnome.istanbul", "/state")
-            self.iface = dbus.Interface(remote_object, "org.gnome.istanbul")
-            self.iface.savemode(False)
-        except:
-            pass
-
-
-        instance.PiTiVi.shutdown()
+    def _destroyCb(self, unused_widget, unused_data=None):
+        self.pitivi.shutdown()
 
 
     def _keyPressEventCb(self, unused_widget, event):
@@ -366,7 +347,7 @@ class PitiviMainWindow(gtk.Window):
 ## Toolbar/Menu actions callback
 
     def _newProjectMenuCb(self, unused_action):
-        instance.PiTiVi.newBlankProject()
+        self.pitivi.newBlankProject()
 
     def _openProjectCb(self, unused_action):
         chooser = gtk.FileChooserDialog(_("Open File ..."),
@@ -391,32 +372,25 @@ class PitiviMainWindow(gtk.Window):
 
         if response == gtk.RESPONSE_OK:
             path = chooser.get_filename()
-            instance.PiTiVi.loadProject(filepath = path)
+            self.pitivi.loadProject(filepath = path)
         chooser.destroy()
         return True
 
     def _saveProjectCb(self, unused_action):
-        instance.PiTiVi.current.save()
+        self.pitivi.current.save()
 
     def _saveProjectAsCb(self, unused_action):
-        instance.PiTiVi.current.saveAs()
+        self.pitivi.current.saveAs()
 
     def _projectSettingsCb(self, unused_action):
-        l = ProjectSettingsDialog(self, instance.PiTiVi.current)
-        l.show()
+        ProjectSettingsDialog(self, self.pitivi.current).show()
 
     def _quitCb(self, unused_action):
-        instance.PiTiVi.shutdown()
+        self.pitivi.shutdown()
 
     def _fullScreenCb(self, unused_action):
         self.toggleFullScreen()
 
-    def _advancedViewCb(self, action):
-        if action.get_active():
-            self.timeline.showComplexView()
-        else:
-            self.timeline.showSimpleView()
-
     def _aboutResponseCb(self, dialog, unused_response):
         dialog.destroy()
 
@@ -425,7 +399,9 @@ class PitiviMainWindow(gtk.Window):
         abt.set_name(APPNAME)
         abt.set_version("v%s" % pitivi_version)
         abt.set_website("http://www.pitivi.org/")
-        authors = ["Edward Hervey <bilboed@bilboed.com>","",_("Contributors:"),
+        authors = ["Edward Hervey <bilboed@bilboed.com>",
+                   "",
+                   _("Contributors:"),
                    "Christophe Sauthier <christophe.sauthier@gmail.com> (i18n)",
                    "Laszlo Pandy <laszlok2@gmail.com> (UI)",
                    "Ernst Persson  <ernstp@gmail.com>",
@@ -438,25 +414,18 @@ class PitiviMainWindow(gtk.Window):
                    "Thijs Vermeir <thijsvermeir@gmail.com>",
                    "Sarath Lakshman <sarathlakshman@slynux.org>"]
         abt.set_authors(authors)
-        abt.set_license(_("GNU Lesser General Public License\nSee http://www.gnu.org/copyleft/lesser.html for more details"))
+        abt.set_license(_("GNU Lesser General Public License\n"
+                          "See http://www.gnu.org/copyleft/lesser.html for more details"))
         abt.set_icon_from_file(configure.get_global_pixmap_dir() + "/pitivi.png")
         abt.connect("response", self._aboutResponseCb)
         abt.show()
 
-    def _importSourcesCb(self, unused_action):
-        self.sourcefactories.sourcelist.showImportSourcesDialog()
-
-    def _importSourcesFolderCb(self, unused_action):
-        self.sourcefactories.sourcelist.showImportSourcesDialog(True)
-
     def _pluginManagerCb(self, unused_action):
-        PluginManagerDialog(instance.PiTiVi.plugin_manager)
-
-
+        PluginManagerDialog(self.pitivi.plugin_manager)
 
     # Import from Webcam callback
     def _ImportWebcam(self,unused_action):
-        w = WebcamManagerDialog(instance.PiTiVi)
+        w = WebcamManagerDialog(self.pitivi)
         w.show()
 
     # Capture network stream callback
@@ -467,7 +436,6 @@ class PitiviMainWindow(gtk.Window):
     def _Screencast(self,unused_action):
         ScreencastManagerDialog()
 
-
     ## Devices changed
     def __deviceChangeCb(self, probe, unused_device):
         if len(probe.getVideoSourceDevices()) < 1:
@@ -477,17 +445,17 @@ class PitiviMainWindow(gtk.Window):
 
     ## PiTiVi main object callbacks
 
-    def _newProjectLoadedCb(self, pitivi, project):
+    def _newProjectLoadedCb(self, unused_pitivi, unused_project):
         gst.log("A NEW project is loaded, update the UI!")
         # ungrey UI
         self.set_sensitive(True)
 
-    def _newProjectLoadingCb(self, pitivi, project):
+    def _newProjectLoadingCb(self, unused_pitivi, unused_project):
         gst.log("A NEW project is being loaded, deactivate UI")
         # grey UI
         self.set_sensitive(False)
 
-    def _closingProjectCb(self, pitivi, project):
+    def _closingProjectCb(self, unused_pitivi, project):
         if not project.hasUnsavedModifications():
             return True
 
@@ -503,15 +471,16 @@ class PitiviMainWindow(gtk.Window):
             return True
         return False
 
-    def _notProjectCb(self, pitivi, reason, uri):
+    def _notProjectCb(self, unused_pitivi, reason, uri):
         # ungrey UI
         dialog = gtk.MessageDialog(self,
             gtk.DIALOG_MODAL,
             gtk.MESSAGE_ERROR,
             gtk.BUTTONS_OK,
-            _("PiTiVi is unable to load file \"%s\": %s") %
-                (uri, reason))
+            _("PiTiVi is unable to load file \"%s\"") %
+                uri)
         dialog.set_title(_("Error Loading File"))
+        dialog.set_property("secondary-text", reason)
         dialog.run()
         dialog.destroy()
         self.set_sensitive(True)
@@ -578,23 +547,13 @@ class PitiviMainWindow(gtk.Window):
         return ret
 
 
-# dbus object class
-class pitivi_dbus(dbus.service.Object):
-    def __init__(self, bus_name, object_path="/import"):
-        dbus.service.Object.__init__(self, bus_name, object_path)
-        self.sourcefactories = SourceFactoriesWidget()
-
-    @dbus.service.method("org.gnome.pitivi")
-    def AddFiles(self, filepath):
-        self.sourcefactories.sourcelist.addFiles(filepath)
-        return True
-
 class EncodingDialog(GladeWindow):
     """ Encoding dialog box """
     glade_file = "encodingdialog.glade"
 
-    def __init__(self, project):
+    def __init__(self, project, instance):
         GladeWindow.__init__(self)
+        self.pitivi = instance
         self.project = project
         self.bin = project.getBin()
         self.bus = self.bin.get_bus()
@@ -652,7 +611,7 @@ class EncodingDialog(GladeWindow):
         if self.outfile and not self.rendering:
             if self.bin.record(self.outfile, self.settings):
                 self.timestarted = time.time()
-                self.positionhandler = instance.PiTiVi.playground.connect('position', self._positionCb)
+                self.positionhandler = self.pitivi.playground.connect('position', self._positionCb)
                 self.rendering = True
                 self.cancelbutton.set_label("gtk-cancel")
                 self.progressbar.set_text(_("Rendering"))
@@ -679,7 +638,7 @@ class EncodingDialog(GladeWindow):
     def _eosCb(self, unused_bus, unused_message):
         self.rendering = False
         if self.positionhandler:
-            instance.PiTiVi.playground.disconnect(self.positionhandler)
+            self.pitivi.playground.disconnect(self.positionhandler)
             self.positionhandler = 0
         self.progressbar.set_text(_("Rendering Complete"))
         self.progressbar.set_fraction(1.0)
@@ -691,7 +650,7 @@ class EncodingDialog(GladeWindow):
     def _cancelButtonClickedCb(self, unused_button):
         self.bin.stopRecording()
         if self.positionhandler:
-            instance.PiTiVi.playground.disconnect(self.positionhandler)
+            self.pitivi.playground.disconnect(self.positionhandler)
             self.positionhandler = 0
-        instance.PiTiVi.playground.pause()
+        self.pitivi.playground.pause()
         self.destroy()
