@@ -27,7 +27,7 @@ import gobject
 import gtk
 import gst
 import pitivi.instance as instance
-from complexinterface import Zoomable
+from zoominterface import Zoomable
 from pitivi.utils import time_to_string
 
 class ScaleRuler(gtk.Layout, Zoomable):
@@ -47,6 +47,7 @@ class ScaleRuler(gtk.Layout, Zoomable):
     def __init__(self, hadj):
         gst.log("Creating new ScaleRule")
         gtk.Layout.__init__(self)
+        Zoomable.__init__(self)
         self.add_events(gtk.gdk.POINTER_MOTION_MASK |
             gtk.gdk.BUTTON_PRESS_MASK | gtk.gdk.BUTTON_RELEASE_MASK)
         self.set_hadjustment(hadj)
@@ -159,9 +160,14 @@ class ScaleRuler(gtk.Layout, Zoomable):
     def _doSeek(self, value, format=gst.FORMAT_TIME):
         gst.debug("seeking to %s / currentlySeeking %r" % (gst.TIME_ARGS (value),
                                                            self.currentlySeeking))
-        if (format == gst.FORMAT_TIME) and (value > self.getDuration()):
-            gst.debug("you can't seek outside of the timeline")
+        # clamping values within acceptable range
+        duration = self.getDuration()
+        if duration == gst.CLOCK_TIME_NONE:
             return
+        if value > duration:
+            value = duration
+        elif value < 0:
+            value = 0
         if not self.currentlySeeking:
             self.currentlySeeking = True
             if instance.PiTiVi.playground.seekInCurrent(value, format=format):
@@ -215,7 +221,10 @@ class ScaleRuler(gtk.Layout, Zoomable):
         self.drawRuler(context, rect)
 
     def getDuration(self):
-        return instance.PiTiVi.current.timeline.getDuration()
+        if instance.PiTiVi.current:
+            return instance.PiTiVi.current.timeline.getDuration()
+        else:
+            return gst.CLOCK_TIME_NONE
 
     def getPixelWidth(self):
         return self.nsToPixel(self.getDuration())
@@ -301,7 +310,7 @@ class ScaleRuler(gtk.Layout, Zoomable):
 
 
         context.save()
-        zoomRatio = self.getZoomRatio()
+        zoomRatio = self.zoomratio
         # looks better largest tick doesn't run into the text label
         interval_sizes = ((60, 0.80), (10, 0.75), (1, 0.5), (0.1, 0.25))
         for interval, height in interval_sizes:
